import React from 'react';

import { GridCol } from '@procyon/components/GridCol';
import { TrashIcon } from '@procyon/components/Icons/Trash';
import List from '@procyon/components/List';
import { StatusEnum } from '@procyon/types/enums';
import { Option } from '@procyon/types/options';

import { Button } from '../../Button';
import { Grid, GridSizeEnum } from '../../Grid';
import { ModalId } from '../../Modal/context';

export type SelectboxModalProps = {
	autoComplete?: boolean;
	closeModal: (id: ModalId) => void;
	name: ModalId;
	onChange: (options: Option) => void;
	onRemove: () => void;
	options: Option[];
	selectedOption: Option | null;
};

const { md } = GridSizeEnum;

export const SelectboxModal: React.FC<SelectboxModalProps> = (props) => {
	const { name, options, autoComplete, selectedOption, onChange, onRemove, closeModal } = props;

	const handleChange = (option: Option) => {
		onChange(option);
		closeModal(name);
	};

	const removeActiveOption = (): void => {
		onRemove();
		closeModal(name);
	};

	return (
		<div>
			<List
				name={name}
				options={options}
				autoComplete={autoComplete}
				selectedCode={selectedOption?.code}
				onChange={handleChange}
			/>
			<Grid cols={{ [md]: 3 }}>
				<GridCol start={{ [md]: 3 }} end={{ [md]: 3 }}>
					<Button label={<TrashIcon fontSize={20} />} status={StatusEnum.warning} onClick={removeActiveOption} blank />
				</GridCol>
			</Grid>
		</div>
	);
};
