import React, { FC, useMemo } from 'react';
import { compose, keys, map } from 'ramda';
import clsx from 'clsx';

import { isNilOrEmpty } from '@procyon/utils';

import type { TableRow as TableRowType } from '../types';
import { TableCol } from '../types';
import { TableCell } from './TableCell';
import { TableHead } from './TableHead';
import TableRow from './TableRow';

export type TableProps = {
	className?: string;
	cols: TableCol;
	nthStyle?: boolean;
	rows: TableRowType[];
};

export const Table: FC<TableProps> = ({ cols, rows, nthStyle = true, className }) => {
	const headCells = useMemo(() => {
		if (!isNilOrEmpty(cols?.data)) {
			return compose(
				map((c) => (
					<TableHead key={c} className={cols.className}>
						{cols.data[c].value}
					</TableHead>
				)),
				keys
			)(cols.data);
		}
		return null;
	}, [cols.data]);

	const body = useMemo(() => {
		if (!rows) {
			return null;
		}
		let rowIndex = 0;
		return map((row) => {
			rowIndex++;
			return (
				<TableRow nthStyle={nthStyle} key={rowIndex} className={row.className}>
					{map((cell) => {
						const head = cols.data[cell];
						return (
							<TableCell
								key={cell}
								title={head.value}
								className={row.data[cell].className}
							>
								{row.data[cell].value}
							</TableCell>
						);
					}, keys(cols.data))}
				</TableRow>
			);
		}, rows);
	}, [cols.data, rows, nthStyle]);

	return (
		<div className={clsx('tablek', className)}>
			<div className="tablek-head-row">{headCells}</div>
			{body}
		</div>
	);
};
